package com.muyu.rule.controller;

import com.dtflys.forest.annotation.Get;
import com.muyu.common.core.domain.Result;
import com.muyu.rule.service.RuleTypeService;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import rule.domain.RuleType;

import java.util.List;

/**
 * @ClassName RuleTypeController
 * @Description 规则类型控制层
 * @Author Chen
 * @Date 2024/8/22 15:34
 */
@RestController
@RequestMapping("/ruleType")
public class RuleTypeController {
    @Autowired
    private RuleTypeService ruleTypeService;

    /**
     * 规则查询
     *
     * @return
     */
    @RequestMapping(path = "/list", method = RequestMethod.POST)
    @Operation(summary = "规则类型", description = "规则类型")
    public Result<List<RuleType>> ruleTypeList() {
        return Result.success(ruleTypeService.list());
    }

    /**
     * 修改
     *
     * @param ruleType
     * @return
     */
    @Operation(summary = "规则类型修改", description = "规则类型修改")
    @PutMapping("/update")
    public Result update(@RequestBody RuleType ruleType) {

        return Result.success(ruleTypeService.updateById(ruleType));
    }

    /**
     * 删除
     *
     * @param id
     * @return
     */
    @Operation(summary = "规则类型删除", description = "规则类型删除")
    @DeleteMapping("/delete/{id}")
    public Result delete(@PathVariable Integer id) {
        return Result.success(ruleTypeService.removeById(id));
    }

    /**
     * 添加
     *
     * @param ruleType
     * @return
     */
    @Operation(summary = "规则类型添加", description = "规则类型添加")
    @PostMapping("/insert")
    public Result insert(@RequestBody RuleType ruleType) {
        return Result.success(ruleTypeService.save(ruleType));
    }

}
